package MT::Plugin::SKR::RebuildFinishNotifier;

use strict;
use MT::Permission;
use MT::Author;
use MT::Template;

use vars qw( $NAME $VERSION );
($NAME) = __PACKAGE__ =~ /.+::(\w+)/;
$VERSION = '0.01';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new ({
    id => $NAME,
    key => $NAME,
    name => $NAME,
    version => $VERSION,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    doc_link => 'http://www.skyarc.co.jp/engineerblog/entry/RebuildFinishNotifier.html',
    description => <<HTMLHEREDOC,
<__trans phrase="Notify by email when rebuilding process has finished">
HTMLHEREDOC
    # Localization
    l10n_class => $NAME. '::L10N',
    # Settings
    blog_config_template => 'tmpl/config.tmpl',
    settings => new MT::PluginSettings([
        ['notification', { Default => 1, Scope => 'blog' }],
    ]),
    # Registry
    registry => {
        callbacks => {
            'MT::App::CMS::template_param.rebuilt' => \&_hdlr_template_param_rebuilt,
        },
    },
});
MT->add_plugin ($plugin);



###
sub _hdlr_template_param_rebuilt {
    my ($cb, $app, $param) = @_;
    my $blog_id = $param->{blog_id};

    my $notification = $plugin->get_config_value ('notification', "blog:$blog_id")
        or return;# do nothing
    my @adress;
    if ($notification == 1) {
        push @adress, $app->user->email;
    }
    elsif ($notification == 2) {
        my %author_id;
        my $iter = MT::Permission->load_iter ({ blog_id => $blog_id });
        while (my $perms = $iter->()) {
            next if $perms->permissions !~ /'(?:administer|rebuild)'/;
            my $author = MT::Author->load ({ id => $perms->author_id })
                or next;
            next if $author_id{$author->email}++;
            push @adress, $author->email;
        }
    }

    # Addresses
    my $cfg = MT->instance->config;
    my $from_addr = $cfg->EmailAddressMain;
    my $reply_to = $cfg->EmailReplyTo
        ? $cfg->EmailReplyTo
        : $cfg->EmailAddressMain;

    # Template
    my $tmpl = MT::Template->new;
    $tmpl->text (q(<__trans phrase="Your [_1] has been published." params="<mt:var name="blog_name">">));
    my $ctx = $tmpl->context;
    $ctx->var ('blog_name', $param->{blog_name});
    my $out = $app->translate_templatized ($tmpl->output);

    require MT::Mail;
    foreach (@adress) {
        my %head = (
            $from_addr ? ( From => $from_addr ) : (),
            $reply_to  ? ( 'Reply-To' => $reply_to ) : (),
            To => $_,
            Subject => $out,
        );
        MT::Mail->send (\%head, $out)
            or die MT::Mail->errstr;
    }
}

1;